@@ -19,6 +19,7 @@
 
 #include <config.h>
 #include <errno.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
@@ -37,32 +38,23 @@
 static int send_query(int fd, int inode, int states, int show)
 {
 	int err;
-	struct sockaddr_nl nladdr = {
-		.nl_family = AF_NETLINK
-	};
+	struct sockaddr_nl nladdr = { .nl_family = AF_NETLINK };
 	struct {
 		struct nlmsghdr nlh;
 		struct unix_diag_req udr;
-	} req = {
-		.nlh = {
-			.nlmsg_len = sizeof(req),.nlmsg_type =
-			SOCK_DIAG_BY_FAMILY,.nlmsg_flags =
-			NLM_F_REQUEST | (inode ? 0 : NLM_F_DUMP)
-			}
-		,.udr = {
-			 .sdiag_family = AF_UNIX,.udiag_states =
-			 states,.udiag_show = show,.udiag_ino = inode}
-	};
-	struct iovec iov = {
-		.iov_base = &req,
-		.iov_len = sizeof(req)
-	};
-	struct msghdr msg = {
-		.msg_name = (void *)&nladdr,
-		.msg_namelen = sizeof(nladdr),
-		.msg_iov = &iov,
-		.msg_iovlen = 1
-	};
+	} req = { .nlh = { .nlmsg_len = sizeof(req),
+			   .nlmsg_type = SOCK_DIAG_BY_FAMILY,
+			   .nlmsg_flags = NLM_F_REQUEST |
+					  (inode ? 0 : NLM_F_DUMP) },
+		  .udr = { .sdiag_family = AF_UNIX,
+			   .udiag_states = states,
+			   .udiag_show = show,
+			   .udiag_ino = inode } };
+	struct iovec iov = { .iov_base = &req, .iov_len = sizeof(req) };
+	struct msghdr msg = { .msg_name = (void *)&nladdr,
+			      .msg_namelen = sizeof(nladdr),
+			      .msg_iov = &iov,
+			      .msg_iovlen = 1 };
 
 	for (;;) {
 		if (sendmsg(fd, &msg, 0) < 0) {
@@ -78,7 +70,7 @@ static int send_query(int fd, int inode, int states, int show)
 	}
 }
 
-typedef int (*process_response)(const struct unix_diag_msg * diag,
+typedef int (*process_response)(const struct unix_diag_msg *diag,
 				unsigned int len, void *context);
 
 struct match_name_context {
@@ -95,12 +87,12 @@ static int match_name(const struct unix_diag_msg *diag, unsigned int len,
 	struct rtattr *attr;
 	unsigned int rta_len = len - NLMSG_LENGTH(sizeof(*diag));
 	size_t path_len = 0;
-	char path[sizeof(((struct sockaddr_un *) 0)->sun_path) + 1];
+	char path[sizeof(((struct sockaddr_un *)0)->sun_path) + 1];
 	struct unix_diag_rqlen rqlen;
 	int rqlen_valid = 0;
 
-	for (attr = (struct rtattr *)(diag + 1);
-	     RTA_OK(attr, rta_len); attr = RTA_NEXT(attr, rta_len)) {
+	for (attr = (struct rtattr *)(diag + 1); RTA_OK(attr, rta_len);
+	     attr = RTA_NEXT(attr, rta_len)) {
 		switch (attr->rta_type) {
 		case UNIX_DIAG_NAME:
 			if (!path_len) {
@@ -142,22 +134,15 @@ static int receive_responses(int fd, process_response process, void *context)
 {
 	int err;
 	long buf[8192 / sizeof(long)];
-	struct sockaddr_nl nladdr = {
-		.nl_family = AF_NETLINK
-	};
-	struct iovec iov = {
-		.iov_base = buf,
-		.iov_len = sizeof(buf)
-	};
+	struct sockaddr_nl nladdr = { .nl_family = AF_NETLINK };
+	struct iovec iov = { .iov_base = buf, .iov_len = sizeof(buf) };
 	int flags = 0;
 
 	for (;;) {
-		struct msghdr msg = {
-			.msg_name = (void *)&nladdr,
-			.msg_namelen = sizeof(nladdr),
-			.msg_iov = &iov,
-			.msg_iovlen = 1
-		};
+		struct msghdr msg = { .msg_name = (void *)&nladdr,
+				      .msg_namelen = sizeof(nladdr),
+				      .msg_iov = &iov,
+				      .msg_iovlen = 1 };
 
 		ssize_t ret = recvmsg(fd, &msg, flags);
 
@@ -191,35 +176,40 @@ static int receive_responses(int fd, process_response process, void *context)
 				const struct nlmsgerr *err = NLMSG_DATA(h);
 
 				if (h->nlmsg_len < NLMSG_LENGTH(sizeof(*err))) {
-					oc_syslog(LOG_ERR,
-					       "nlmsg_type NLMSG_ERROR has short nlmsg_len %d",
-					       h->nlmsg_len);
+					oc_syslog(
+						LOG_ERR,
+						"nlmsg_type NLMSG_ERROR has short nlmsg_len %" PRIu32,
+						h->nlmsg_len);
 				} else {
-					oc_syslog(LOG_ERR, "NLM query failed %s",
-					       strerror(-err->error));
+					oc_syslog(LOG_ERR,
+						  "NLM query failed %s",
+						  strerror(-err->error));
 				}
 
 				return -1;
 			}
 
 			if (h->nlmsg_type != SOCK_DIAG_BY_FAMILY) {
-				oc_syslog(LOG_ERR, "unexpected nlmsg_type %u\n",
-				       (unsigned)h->nlmsg_type);
+				oc_syslog(LOG_ERR,
+					  "unexpected nlmsg_type %" PRIu16 "\n",
+					  h->nlmsg_type);
 				return -1;
 			}
 
 			diag = (const struct unix_diag_msg *)NLMSG_DATA(h);
 
 			if (h->nlmsg_len < NLMSG_LENGTH(sizeof(*diag))) {
-				oc_syslog(LOG_ERR,
-				       "nlmsg_type SOCK_DIAG_BY_FAMILY has short nlmsg_len %d",
-				       h->nlmsg_len);
+				oc_syslog(
+					LOG_ERR,
+					"nlmsg_type SOCK_DIAG_BY_FAMILY has short nlmsg_len %" PRIu32,
+					h->nlmsg_len);
 				return -1;
 			}
 
 			if (diag->udiag_family != AF_UNIX) {
-				oc_syslog(LOG_ERR, "unexpected family %u\n",
-				       diag->udiag_family);
+				oc_syslog(LOG_ERR,
+					  "unexpected family %" PRIu8 "\n",
+					  diag->udiag_family);
 				return -1;
 			}
 
@@ -235,10 +225,7 @@ int sockdiag_query_unix_domain_socket_queue_length(const char *socket_name,
 {
 	int err;
 	int ret = -1;
-	struct match_name_context ctx = {
-		.name = socket_name,
-		.inode = 0
-	};
+	struct match_name_context ctx = { .name = socket_name, .inode = 0 };
 
 	int fd = socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG);
 
@@ -248,8 +235,8 @@ int sockdiag_query_unix_domain_socket_queue_length(const char *socket_name,
 		goto cleanup;
 	}
 
-	if (send_query
-	    (fd, 0, 1 << TCP_LISTEN, UDIAG_SHOW_NAME | UDIAG_SHOW_RQLEN))
+	if (send_query(fd, 0, 1 << TCP_LISTEN,
+		       UDIAG_SHOW_NAME | UDIAG_SHOW_RQLEN))
 		goto cleanup;
 
 	if (receive_responses(fd, match_name, &ctx))
@@ -260,7 +247,7 @@ int sockdiag_query_unix_domain_socket_queue_length(const char *socket_name,
 
 	ret = 0;
 
- cleanup:
+cleanup:
 	if (fd >= 0) {
 		close(fd);
 	}
