@@ -16,9 +16,11 @@
  */
 
 #ifndef OC_LZS_H
-# define OC_LZS_H
+#define OC_LZS_H
 
-int lzs_decompress(unsigned char *dst, int dstlen, const unsigned char *src, int srclen);
-int lzs_compress(unsigned char *dst, int dstlen, const unsigned char *src, int srclen);
+int lzs_decompress(unsigned char *dst, int dstlen, const unsigned char *src,
+		   int srclen);
+int lzs_compress(unsigned char *dst, int dstlen, const unsigned char *src,
+		 int srclen);
 
 #endif
