@@ -25,14 +25,14 @@
 #include <stdint.h>
 #include <unistd.h>
 #include <gnutls/gnutls.h>
-#include <gnutls/crypto.h>	/* for random */
+#include <gnutls/crypto.h> /* for random */
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <getopt.h>
 #ifdef HAVE_CRYPT_H
-  /* libcrypt in Fedora28 does not provide prototype
+/* libcrypt in Fedora28 does not provide prototype
    * in unistd.h */
-# include <crypt.h>
+#include <crypt.h>
 #endif
 #include <locale.h>
 
@@ -42,18 +42,17 @@ static const char alphabet[] =
 	"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ./";
 
 #define SALT_SIZE 16
-static void
-crypt_int(const char *fpasswd, const char *username, const char *groupname,
-	  const char *passwd)
+static void crypt_int(const char *fpasswd, const char *username,
+		      const char *groupname, const char *passwd)
 {
 	uint8_t _salt[SALT_SIZE];
-	char salt[SALT_SIZE+16];
+	char salt[SALT_SIZE + 16];
 	char *p, *cr_passwd;
 	char *tmp_passwd;
-	unsigned i;
-	unsigned fpasswd_len = strlen(fpasswd);
-	unsigned tmp_passwd_len;
-	unsigned username_len = strlen(username);
+	unsigned int i;
+	unsigned int fpasswd_len = strlen(fpasswd);
+	unsigned int tmp_passwd_len;
+	unsigned int username_len = strlen(username);
 	struct stat st;
 	FILE *fd, *fd2;
 	char *line = NULL;
@@ -121,14 +120,17 @@ crypt_int(const char *fpasswd, const char *username, const char *groupname,
 		fprintf(fd2, "%s:%s:%s\n", username, groupname, cr_passwd);
 	} else {
 		int found = 0;
+
 		while ((len = getline(&line, &line_size, fd)) > 0) {
 			p = strchr(line, ':');
 			if (p == NULL)
 				continue;
 
-			l = p-line;
-			if (l == username_len && strncmp(line, username, l) == 0) {
-				fprintf(fd2, "%s:%s:%s\n", username, groupname, cr_passwd); /* lgtm[cpp/cleartext-storage-file] */
+			l = p - line;
+			if (l == username_len &&
+			    strncmp(line, username, l) == 0) {
+				fprintf(fd2, "%s:%s:%s\n", username, groupname,
+					cr_passwd); /* lgtm[cpp/cleartext-storage-file] */
 				found = 1;
 			} else {
 				fwrite(line, 1, len, fd2);
@@ -138,7 +140,8 @@ crypt_int(const char *fpasswd, const char *username, const char *groupname,
 		fclose(fd);
 
 		if (found == 0)
-			fprintf(fd2, "%s:%s:%s\n", username, groupname, cr_passwd); /* lgtm[cpp/cleartext-storage-file] */
+			fprintf(fd2, "%s:%s:%s\n", username, groupname,
+				cr_passwd); /* lgtm[cpp/cleartext-storage-file] */
 	}
 
 	fclose(fd2);
@@ -151,15 +154,14 @@ crypt_int(const char *fpasswd, const char *username, const char *groupname,
 	free(tmp_passwd);
 }
 
-static void
-delete_user(const char *fpasswd, const char *username)
+static void delete_user(const char *fpasswd, const char *username)
 {
-	FILE * fd, *fd2;
+	FILE *fd, *fd2;
 	char *tmp_passwd;
 	char *line, *p;
-	unsigned fpasswd_len = strlen(fpasswd);
-	unsigned tmp_passwd_len;
-	unsigned username_len = strlen(username);
+	unsigned int fpasswd_len = strlen(fpasswd);
+	unsigned int tmp_passwd_len;
+	unsigned int username_len = strlen(username);
 	int ret;
 	ssize_t len, l;
 	size_t line_size;
@@ -196,7 +198,7 @@ delete_user(const char *fpasswd, const char *username)
 		if (p == NULL)
 			continue;
 
-		l = p-line;
+		l = p - line;
 		if (l == username_len && strncmp(line, username, l) == 0) {
 			continue;
 		} else {
@@ -216,15 +218,14 @@ delete_user(const char *fpasswd, const char *username)
 	free(tmp_passwd);
 }
 
-static void
-lock_user(const char *fpasswd, const char *username)
+static void lock_user(const char *fpasswd, const char *username)
 {
-	FILE * fd, *fd2;
+	FILE *fd, *fd2;
 	char *tmp_passwd;
 	char *line, *p;
-	unsigned fpasswd_len = strlen(fpasswd);
-	unsigned tmp_passwd_len;
-	unsigned username_len = strlen(username);
+	unsigned int fpasswd_len = strlen(fpasswd);
+	unsigned int tmp_passwd_len;
+	unsigned int username_len = strlen(username);
 	int ret;
 	ssize_t len, l;
 	size_t line_size;
@@ -261,18 +262,18 @@ lock_user(const char *fpasswd, const char *username)
 		if (p == NULL)
 			continue;
 
-		l = p-line;
+		l = p - line;
 		if (l == username_len && strncmp(line, username, l) == 0) {
-			p = strchr(p+1, ':');
+			p = strchr(p + 1, ':');
 			if (p == NULL)
 				continue;
 			p++;
 
 			if (*p != '!') {
-				l = p-line;
+				l = p - line;
 				fwrite(line, 1, l, fd2);
 				fputc('!', fd2);
-				fwrite(p, 1, len-l, fd2);
+				fwrite(p, 1, len - l, fd2);
 			} else {
 				fwrite(line, 1, len, fd2);
 			}
@@ -293,15 +294,14 @@ lock_user(const char *fpasswd, const char *username)
 	free(tmp_passwd);
 }
 
-static void
-unlock_user(const char *fpasswd, const char *username)
+static void unlock_user(const char *fpasswd, const char *username)
 {
-	FILE * fd, *fd2;
+	FILE *fd, *fd2;
 	char *tmp_passwd;
 	char *line, *p;
-	unsigned fpasswd_len = strlen(fpasswd);
-	unsigned tmp_passwd_len;
-	unsigned username_len = strlen(username);
+	unsigned int fpasswd_len = strlen(fpasswd);
+	unsigned int tmp_passwd_len;
+	unsigned int username_len = strlen(username);
 	int ret;
 	ssize_t len, l;
 	size_t line_size;
@@ -338,19 +338,20 @@ unlock_user(const char *fpasswd, const char *username)
 		if (p == NULL)
 			continue;
 
-		l = p-line;
+		l = p - line;
 		if (l == username_len && strncmp(line, username, l) == 0) {
-			p = strchr(p+1, ':');
+			p = strchr(p + 1, ':');
 			if (p == NULL)
 				continue;
 			p++;
 
-			l = p-line;
+			l = p - line;
 			fwrite(line, 1, l, fd2);
 
-			if (*p=='!') p++;
-			l = p-line;
-			fwrite(p, 1, len-l, fd2);
+			if (*p == '!')
+				p++;
+			l = p - line;
+			fwrite(p, 1, len - l, fd2);
 		} else {
 			fwrite(line, 1, len, fd2);
 		}
@@ -369,63 +370,67 @@ unlock_user(const char *fpasswd, const char *username)
 }
 
 static const struct option long_options[] = {
-	{"passwd", 1, 0, 'c'},
-	{"groupname", 1, 0, 'g'},
-	{"delete", 0, 0, 'd'},
-	{"lock", 0, 0, 'l'},
-	{"unlock", 0, 0, 'u'},
-	{"help", 0, 0, 'h'},
-	{"version", 0, 0, 'v'},
-	{NULL, 0, 0, 0}
+	{ "passwd", 1, 0, 'c' },  { "groupname", 1, 0, 'g' },
+	{ "delete", 0, 0, 'd' },  { "lock", 0, 0, 'l' },
+	{ "unlock", 0, 0, 'u' },  { "help", 0, 0, 'h' },
+	{ "version", 0, 0, 'v' }, { NULL, 0, 0, 0 }
 };
 
-static
-void usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "ocpasswd - OpenConnect server password utility\n");
-	fprintf(stderr, "Usage:  ocpasswd [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [username]\n");
+	fprintf(stderr,
+		"Usage:  ocpasswd [ -<flag> [<val>] | --<name>[{=| }<val>] ]... username\n");
 	fprintf(stderr, "\n");
 	fprintf(stderr, "   -c, --passwd=file          Password file\n");
 	fprintf(stderr, "   -g, --groupname=str        User's group name\n");
 	fprintf(stderr, "   -d, --delete               Delete user\n");
 	fprintf(stderr, "   -l, --lock                 Lock user\n");
 	fprintf(stderr, "   -u, --unlock               Unlock user\n");
-	fprintf(stderr, "   -v, --version              output version information and exit\n");
-	fprintf(stderr, "   -h, --help                 display extended usage information and exit\n");
+	fprintf(stderr,
+		"   -v, --version              output version information and exit\n");
+	fprintf(stderr,
+		"   -h, --help                 display extended usage information and exit\n");
 	fprintf(stderr, "\n");
-	fprintf(stderr, "Options are specified by doubled hyphens and their name or by a single\n");
+	fprintf(stderr,
+		"Options are specified by doubled hyphens and their name or by a single\n");
 	fprintf(stderr, "hyphen and the flag character.\n\n");
-	fprintf(stderr, "This program is openconnect password (ocpasswd) utility.  It allows the\n");
-	fprintf(stderr, "generation and handling of a 'plain' password file used by ocserv.\n\n");
-	fprintf(stderr, "Please file bug reports at:  "PACKAGE_BUGREPORT"\n");
+	fprintf(stderr,
+		"This program is openconnect password (ocpasswd) utility.  It allows the\n");
+	fprintf(stderr,
+		"generation and handling of a 'plain' password file used by ocserv.\n\n");
+	fprintf(stderr, "Please file bug reports at:  " PACKAGE_BUGREPORT "\n");
 }
 
-static
-void version(void)
+static void version(void)
 {
-	fprintf(stderr, "ocpasswd - "VERSION"\n");
-	fprintf(stderr, "Copyright (C) 2013-2017 Nikos Mavrogiannopoulos, all rights reserved.\n");
-	fprintf(stderr, "This is free software. It is licensed for use, modification and\n");
-	fprintf(stderr, "redistribution under the terms of the GNU General Public License,\n");
+	fprintf(stderr, "ocpasswd - " VERSION "\n");
+	fprintf(stderr,
+		"Copyright (C) 2013-2017 Nikos Mavrogiannopoulos, all rights reserved.\n");
+	fprintf(stderr,
+		"This is free software. It is licensed for use, modification and\n");
+	fprintf(stderr,
+		"redistribution under the terms of the GNU General Public License,\n");
 	fprintf(stderr, "version 2 <http://gnu.org/licenses/gpl.html>\n\n");
-	fprintf(stderr, "Please file bug reports at:  "PACKAGE_BUGREPORT"\n");
+	fprintf(stderr, "Please file bug reports at:  " PACKAGE_BUGREPORT "\n");
 }
 
 #define FLAG_DELETE 1
-#define FLAG_LOCK (1<<1)
-#define FLAG_UNLOCK (1<<2)
+#define FLAG_LOCK (1 << 1)
+#define FLAG_UNLOCK (1 << 2)
 
-int main(int argc, char **argv)
+int main(int argc, char *argv[])
 {
 	int ret, c;
 	const char *username = NULL;
 	char *groupname = NULL, *fpasswd = NULL;
-	char* passwd = NULL;
-	unsigned free_passwd = 0;
+	char *passwd = NULL;
+	unsigned int free_passwd = 0;
 	size_t l, i;
-	unsigned flags = 0;
+	unsigned int flags = 0;
 
-	if ((ret = gnutls_global_init()) < 0) {
+	ret = gnutls_global_init();
+	if (ret < 0) {
 		fprintf(stderr, "global_init: %s\n", gnutls_strerror(ret));
 		exit(EXIT_FAILURE);
 	}
@@ -440,14 +445,16 @@ int main(int argc, char **argv)
 		switch (c) {
 		case 'c':
 			if (fpasswd) {
-				fprintf(stderr, "-c option cannot be specified multiple time\n");
+				fprintf(stderr,
+					"-c option cannot be specified multiple time\n");
 				exit(EXIT_FAILURE);
 			}
 			fpasswd = strdup(optarg);
 			break;
 		case 'g':
 			if (groupname) {
-				fprintf(stderr, "-g option cannot be specified multiple time\n");
+				fprintf(stderr,
+					"-g option cannot be specified multiple time\n");
 				exit(EXIT_FAILURE);
 			}
 			groupname = strdup(optarg);
@@ -482,7 +489,7 @@ int main(int argc, char **argv)
 		}
 	}
 
-	if (optind < argc && argc-optind == 1) {
+	if (optind < argc && argc - optind == 1) {
 		username = argv[optind++];
 	} else {
 		usage();
@@ -491,8 +498,16 @@ int main(int argc, char **argv)
 
 	if (!groupname)
 		groupname = strdup("*");
+	if (!groupname) {
+		fprintf(stderr, "memory error\n");
+		exit(EXIT_FAILURE);
+	}
 	if (!fpasswd)
 		fpasswd = strdup(DEFAULT_OCPASSWD);
+	if (!fpasswd) {
+		fprintf(stderr, "memory error\n");
+		exit(EXIT_FAILURE);
+	}
 
 	if (flags & FLAG_LOCK) {
 		lock_user(fpasswd, username);
@@ -503,7 +518,7 @@ int main(int argc, char **argv)
 	} else { /* set password */
 
 		if (isatty(STDIN_FILENO)) {
-			char* p2;
+			char *p2;
 
 			passwd = getpass("Enter password: ");
 			if (passwd == NULL) {
@@ -511,7 +526,6 @@ int main(int argc, char **argv)
 				exit(EXIT_FAILURE);
 			}
 
-
 			p2 = strdup(passwd);
 			passwd = getpass("Re-enter password: ");
 			if (passwd == NULL) {
@@ -533,8 +547,8 @@ int main(int argc, char **argv)
 			}
 
 			free_passwd = 1;
-			if (passwd[l-1] == '\n')
-				passwd[l-1] = 0;
+			if (passwd[l - 1] == '\n')
+				passwd[l - 1] = 0;
 		}
 
 		crypt_int(fpasswd, username, groupname, passwd);
