@@ -39,8 +39,7 @@
 #include <ip-util.h>
 #include <tlslib.h>
 
-int handle_resume_delete_req(sec_mod_st *sec,
-			     const SessionResumeFetchMsg *req)
+int handle_resume_delete_req(sec_mod_st *sec, const SessionResumeFetchMsg *req)
 {
 	tls_cache_st *cache;
 	struct htable_iter iter;
@@ -53,7 +52,6 @@ int handle_resume_delete_req(sec_mod_st *sec,
 		if (req->session_id.len == cache->session_id_size &&
 		    memcmp(req->session_id.data, cache->session_id,
 			   req->session_id.len) == 0) {
-
 			cache->session_data_size = 0;
 			cache->session_id_size = 0;
 
@@ -69,8 +67,7 @@ int handle_resume_delete_req(sec_mod_st *sec,
 	return 0;
 }
 
-int handle_resume_fetch_req(sec_mod_st *sec,
-			    const SessionResumeFetchMsg *req,
+int handle_resume_fetch_req(sec_mod_st *sec, const SessionResumeFetchMsg *req,
 			    SessionResumeReplyMsg *rep)
 {
 	tls_cache_st *cache;
@@ -86,28 +83,29 @@ int handle_resume_fetch_req(sec_mod_st *sec,
 		if (req->session_id.len == cache->session_id_size &&
 		    memcmp(req->session_id.data, cache->session_id,
 			   req->session_id.len) == 0) {
-
-			if (req->vhost && cache->vhostname && strcasecmp(req->vhost, cache->vhostname) != 0)
+			if (req->vhost && cache->vhostname &&
+			    strcasecmp(req->vhost, cache->vhostname) != 0)
 				return 0;
 			else if (req->vhost != cache->vhostname)
 				return 0;
 
 			if (req->cli_addr.len == cache->remote_addr_len &&
-			    ip_cmp((struct sockaddr_storage *)req->cli_addr.data, &cache->remote_addr) == 0) {
-
+			    ip_cmp((struct sockaddr_storage *)req->cli_addr.data,
+				   &cache->remote_addr) == 0) {
 				rep->reply =
-				    SESSION_RESUME_REPLY_MSG__RESUME__REP__OK;
+					SESSION_RESUME_REPLY_MSG__RESUME__REP__OK;
 
 				rep->has_session_data = 1;
 
 				rep->session_data.data =
-				    (void *)cache->session_data;
+					(void *)cache->session_data;
 				rep->session_data.len =
-				    cache->session_data_size;
+					cache->session_data_size;
 
-				seclog_hex(sec, LOG_DEBUG, "TLS session DB resuming",
-					  req->session_id.data,
-					  req->session_id.len, 0);
+				seclog_hex(sec, LOG_DEBUG,
+					   "TLS session DB resuming",
+					   req->session_id.data,
+					   req->session_id.len, 0);
 
 				return 0;
 			}
@@ -117,7 +115,6 @@ int handle_resume_fetch_req(sec_mod_st *sec,
 	}
 
 	return 0;
-
 }
 
 int handle_resume_store_req(sec_mod_st *sec,
@@ -132,17 +129,17 @@ int handle_resume_store_req(sec_mod_st *sec,
 	if (req->session_data.len > MAX_SESSION_DATA_SIZE)
 		return -1;
 
-	max = MAX(2 * GETCONFIG(sec)->max_clients, DEFAULT_MAX_CACHED_TLS_SESSIONS);
+	max = MAX(2 * GETCONFIG(sec)->max_clients,
+		  DEFAULT_MAX_CACHED_TLS_SESSIONS);
 	if (sec->tls_db.entries >= max) {
 		seclog(sec, LOG_INFO,
-		      "maximum number of stored TLS sessions reached (%u)",
-		      max);
+		       "maximum number of stored TLS sessions reached (%u)",
+		       max);
 		return -1;
 	}
 
 	if (req->cli_addr.len == 0) {
-		seclog(sec, LOG_INFO,
-		      "invalid address length");
+		seclog(sec, LOG_INFO, "invalid address length");
 		return -1;
 	}
 
@@ -167,14 +164,13 @@ int handle_resume_store_req(sec_mod_st *sec,
 
 	if (htable_add(sec->tls_db.ht, key, cache) == 0) {
 		seclog(sec, LOG_INFO,
-		      "could not add TLS session to hash table");
+		       "could not add TLS session to hash table");
 		talloc_free(cache);
 	} else {
 		sec->tls_db.entries++;
 
 		seclog_hex(sec, LOG_DEBUG, "TLS session DB storing",
-					req->session_id.data,
-					req->session_id.len, 0);
+			   req->session_id.data, req->session_id.len, 0);
 	}
 
 	return 0;
@@ -202,7 +198,8 @@ void expire_tls_sessions(sec_mod_st *sec)
 
 			htable_delval(sec->tls_db.ht, &iter);
 
-			safe_memset(cache->session_data, 0, cache->session_data_size);
+			safe_memset(cache->session_data, 0,
+				    cache->session_data_size);
 			talloc_free(cache);
 			sec->tls_db.entries--;
 		}
