@@ -29,10 +29,12 @@
 #include <vpn.h>
 #include "common-config.h"
 
-static void free_expanded_brackets_string(subcfg_val_st out[MAX_SUBOPTIONS], unsigned size)
+static void free_expanded_brackets_string(subcfg_val_st out[MAX_SUBOPTIONS],
+					  unsigned int size)
 {
-	unsigned i;
-	for (i=0;i<size;i++) {
+	unsigned int i;
+
+	for (i = 0; i < size; i++) {
 		talloc_free(out[i].name);
 		talloc_free(out[i].value);
 	}
@@ -40,12 +42,12 @@ static void free_expanded_brackets_string(subcfg_val_st out[MAX_SUBOPTIONS], uns
 
 /* Returns the number of suboptions processed.
  */
-static
-unsigned expand_brackets_string(void *pool, const char *str, subcfg_val_st out[MAX_SUBOPTIONS])
+static unsigned int expand_brackets_string(void *pool, const char *str,
+					   subcfg_val_st out[MAX_SUBOPTIONS])
 {
 	char *p, *p2, *p3;
-	unsigned len, len2;
-	unsigned pos = 0, finish = 0;
+	unsigned int len, len2;
+	unsigned int pos = 0, finish = 0;
 
 	if (str == NULL)
 		return 0;
@@ -82,19 +84,19 @@ unsigned expand_brackets_string(void *pool, const char *str, subcfg_val_st out[M
 		len2 = p3 - p2;
 
 		if (len > 0) {
-			while (isspace(p[len-1]))
+			while (isspace(p[len - 1]))
 				len--;
 		}
 		if (len2 > 0) {
-			while (isspace(p2[len2-1]))
+			while (isspace(p2[len2 - 1]))
 				len2--;
 		}
 
 		out[pos].name = talloc_strndup(pool, p, len);
 		out[pos].value = talloc_strndup(pool, p2, len2);
 		pos++;
-		p = p2+len2;
-		while (isspace(*p)||*p==',')
+		p = p2 + len2;
+		while (isspace(*p) || *p == ',')
 			p++;
 	} while (finish == 0 && pos < MAX_SUBOPTIONS);
 
@@ -102,10 +104,11 @@ unsigned expand_brackets_string(void *pool, const char *str, subcfg_val_st out[M
 }
 
 #ifdef HAVE_GSSAPI
-void *gssapi_get_brackets_string(void *pool, struct perm_cfg_st *config, const char *str)
+void *gssapi_get_brackets_string(void *pool, struct perm_cfg_st *config,
+				 const char *str)
 {
 	subcfg_val_st vals[MAX_SUBOPTIONS];
-	unsigned vals_size, i;
+	unsigned int vals_size, i;
 	gssapi_cfg_st *additional;
 
 	additional = talloc_zero(pool, gssapi_cfg_st);
@@ -114,22 +117,27 @@ void *gssapi_get_brackets_string(void *pool, struct perm_cfg_st *config, const c
 	}
 
 	vals_size = expand_brackets_string(pool, str, vals);
-	for (i=0;i<vals_size;i++) {
+	for (i = 0; i < vals_size; i++) {
 		if (strcasecmp(vals[i].name, "keytab") == 0) {
 			additional->keytab = vals[i].value;
 			vals[i].value = NULL;
-		} else if (strcasecmp(vals[i].name, "require-local-user-map") == 0) {
-			additional->no_local_map = 1-CHECK_TRUE(vals[i].value);
-		} else if (strcasecmp(vals[i].name, "tgt-freshness-time") == 0) {
+		} else if (strcasecmp(vals[i].name, "require-local-user-map") ==
+			   0) {
+			additional->no_local_map =
+				1 - CHECK_TRUE(vals[i].value);
+		} else if (strcasecmp(vals[i].name, "tgt-freshness-time") ==
+			   0) {
 			additional->ticket_freshness_secs = atoi(vals[i].value);
 			if (additional->ticket_freshness_secs == 0) {
-				fprintf(stderr, "Invalid value for '%s': %s\n", vals[i].name, vals[i].value);
+				fprintf(stderr, "Invalid value for '%s': %s\n",
+					vals[i].name, vals[i].value);
 				exit(EXIT_FAILURE);
 			}
 		} else if (strcasecmp(vals[i].name, "gid-min") == 0) {
 			additional->gid_min = atoi(vals[i].value);
 			if (additional->gid_min < 0) {
-				fprintf(stderr, "error in gid-min value: %d\n", additional->gid_min);
+				fprintf(stderr, "error in gid-min value: %d\n",
+					additional->gid_min);
 				exit(EXIT_FAILURE);
 			}
 		} else {
@@ -145,7 +153,7 @@ void *gssapi_get_brackets_string(void *pool, struct perm_cfg_st *config, const c
 void *get_brackets_string1(void *pool, const char *str)
 {
 	char *p, *p2;
-	unsigned len;
+	unsigned int len;
 
 	p = strchr(str, '[');
 	if (p == NULL) {
@@ -173,7 +181,7 @@ void *get_brackets_string1(void *pool, const char *str)
 static void *get_brackets_string2(void *pool, const char *str)
 {
 	char *p, *p2;
-	unsigned len;
+	unsigned int len;
 
 	p = strchr(str, '[');
 	if (p == NULL) {
@@ -204,11 +212,12 @@ static void *get_brackets_string2(void *pool, const char *str)
 	return talloc_strndup(pool, p, len);
 }
 
-void *radius_get_brackets_string(void *pool, struct perm_cfg_st *config, const char *str)
+void *radius_get_brackets_string(void *pool, struct perm_cfg_st *config,
+				 const char *str)
 {
 	char *p;
 	subcfg_val_st vals[MAX_SUBOPTIONS];
-	unsigned vals_size, i;
+	unsigned int vals_size, i;
 	radius_cfg_st *additional;
 
 	additional = talloc_zero(pool, radius_cfg_st);
@@ -216,13 +225,16 @@ void *radius_get_brackets_string(void *pool, struct perm_cfg_st *config, const c
 		return NULL;
 	}
 
-	if (str && str[0] == '[' && (str[1] == '/' || str[1] == '.')) { /* legacy format */
+	if (str && str[0] == '[' &&
+	    (str[1] == '/' || str[1] == '.')) { /* legacy format */
 		additional->config = get_brackets_string1(pool, str);
 
 		p = get_brackets_string2(config, str);
 		if (p != NULL) {
 			if (strcasecmp(p, "groupconfig") != 0) {
-				fprintf(stderr, "No known configuration option: %s\n", p);
+				fprintf(stderr,
+					"No known configuration option: %s\n",
+					p);
 				exit(EXIT_FAILURE);
 			}
 			config->sup_config_type = SUP_CONFIG_RADIUS;
@@ -230,18 +242,22 @@ void *radius_get_brackets_string(void *pool, struct perm_cfg_st *config, const c
 	} else {
 		/* new format */
 		vals_size = expand_brackets_string(pool, str, vals);
-		for (i=0;i<vals_size;i++) {
+		for (i = 0; i < vals_size; i++) {
 			if (strcasecmp(vals[i].name, "config") == 0) {
 				additional->config = vals[i].value;
 				vals[i].value = NULL;
-			} else if (strcasecmp(vals[i].name, "nas-identifier") == 0) {
+			} else if (strcasecmp(vals[i].name, "nas-identifier") ==
+				   0) {
 				additional->nas_identifier = vals[i].value;
 				vals[i].value = NULL;
-			} else if (strcasecmp(vals[i].name, "groupconfig") == 0) {
+			} else if (strcasecmp(vals[i].name, "groupconfig") ==
+				   0) {
 				if (CHECK_TRUE(vals[i].value))
-					config->sup_config_type = SUP_CONFIG_RADIUS;
+					config->sup_config_type =
+						SUP_CONFIG_RADIUS;
 			} else {
-				fprintf(stderr, "unknown option '%s'\n", vals[i].name);
+				fprintf(stderr, "unknown option '%s'\n",
+					vals[i].name);
 				exit(EXIT_FAILURE);
 			}
 		}
@@ -258,10 +274,11 @@ void *radius_get_brackets_string(void *pool, struct perm_cfg_st *config, const c
 #endif
 
 #ifdef HAVE_PAM
-void *pam_get_brackets_string(void *pool, struct perm_cfg_st *config, const char *str)
+void *pam_get_brackets_string(void *pool, struct perm_cfg_st *config,
+			      const char *str)
 {
 	subcfg_val_st vals[MAX_SUBOPTIONS];
-	unsigned vals_size, i;
+	unsigned int vals_size, i;
 	pam_cfg_st *additional;
 
 	additional = talloc_zero(pool, pam_cfg_st);
@@ -271,11 +288,12 @@ void *pam_get_brackets_string(void *pool, struct perm_cfg_st *config, const char
 
 	/* new format */
 	vals_size = expand_brackets_string(pool, str, vals);
-	for (i=0;i<vals_size;i++) {
+	for (i = 0; i < vals_size; i++) {
 		if (strcasecmp(vals[i].name, "gid-min") == 0) {
 			additional->gid_min = atoi(vals[i].value);
 			if (additional->gid_min < 0) {
-				fprintf(stderr, "error in gid-min value: %d\n", additional->gid_min);
+				fprintf(stderr, "error in gid-min value: %d\n",
+					additional->gid_min);
 				exit(EXIT_FAILURE);
 			}
 		} else {
@@ -289,10 +307,11 @@ void *pam_get_brackets_string(void *pool, struct perm_cfg_st *config, const char
 }
 #endif
 
-void *plain_get_brackets_string(void *pool, struct perm_cfg_st *config, const char *str)
+void *plain_get_brackets_string(void *pool, struct perm_cfg_st *config,
+				const char *str)
 {
 	subcfg_val_st vals[MAX_SUBOPTIONS];
-	unsigned vals_size, i;
+	unsigned int vals_size, i;
 	plain_cfg_st *additional;
 
 	additional = talloc_zero(pool, plain_cfg_st);
@@ -300,11 +319,12 @@ void *plain_get_brackets_string(void *pool, struct perm_cfg_st *config, const ch
 		return NULL;
 	}
 
-	if (str && str[0] == '[' && (str[1] == '/' || str[1] == '.')) { /* legacy format */
+	if (str && str[0] == '[' &&
+	    (str[1] == '/' || str[1] == '.')) { /* legacy format */
 		additional->passwd = get_brackets_string1(pool, str);
 	} else {
 		vals_size = expand_brackets_string(pool, str, vals);
-		for (i=0;i<vals_size;i++) {
+		for (i = 0; i < vals_size; i++) {
 			if (strcasecmp(vals[i].name, "passwd") == 0) {
 				additional->passwd = vals[i].value;
 				vals[i].value = NULL;
@@ -314,7 +334,8 @@ void *plain_get_brackets_string(void *pool, struct perm_cfg_st *config, const ch
 				vals[i].value = NULL;
 #endif
 			} else {
-				fprintf(stderr, "unknown option '%s'\n", vals[i].name);
+				fprintf(stderr, "unknown option '%s'\n",
+					vals[i].name);
 				exit(EXIT_FAILURE);
 			}
 		}
@@ -329,17 +350,17 @@ void *plain_get_brackets_string(void *pool, struct perm_cfg_st *config, const ch
 	return additional;
 }
 
-
-void *oidc_get_brackets_string(void * pool, struct perm_cfg_st *config, const char *str)
+void *oidc_get_brackets_string(void *pool, struct perm_cfg_st *config,
+			       const char *str)
 {
 	subcfg_val_st vals[MAX_SUBOPTIONS];
-	char * additional = NULL;
+	char *additional = NULL;
 
-	unsigned vals_size, i;
+	unsigned int vals_size, i;
 
-	vals_size  = expand_brackets_string(pool, str, vals);
+	vals_size = expand_brackets_string(pool, str, vals);
 
-	for (i = 0; i < vals_size; i ++)	{
+	for (i = 0; i < vals_size; i++) {
 		if (strcasecmp(vals[i].name, "config") == 0) {
 			additional = talloc_strdup(pool, vals[i].value);
 		}
